@@ -12,7 +12,7 @@ from scipy import constants
 from os.path import normcase, split, join
 
 
-class Molecule:
+class Molecule_sts:
     """Molecule class for a state-to-state approximation
     Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
     dissociation-related partition functions, etc.
